# CaraML Google Authentication

Utility package containing functions to authenticate users of the Python SDKs of CaraML.

## Installation

To install via `pip`:
```shell
pip install caraml-auth-google
```

To specify this in a `requirements.txt` file:
```txt
# Other dependencies here
caraml-auth-google
```

## Unit Tests

To run the unit tests, run the following command:
```shell
make test
```